<?php

/*

LIBRARY

----------

Load the required library for theme.

----------*/

require_once 'lib/customizer.php';

require_once 'lib/widget-master.php';



/*

WIDGET

----------

Load custom widgets for theme.

----------*/

get_template_part('modules/widgets/posts', 'slider');

get_template_part('modules/widgets/posts', 'tabs');

get_template_part('modules/widgets/posts', 'medium-thumb');



/*

INIT

----------

init action hook & filter hook for "after_setup_theme"

----------*/

add_action('after_setup_theme', 'seramag_lite_after_setup_theme');





function seramag_lite_after_setup_theme() {



    load_theme_textdomain('seramag_lite', get_template_directory() . '/languages');

    add_theme_support('title-tag');

    add_theme_support('post-thumbnails');

    add_theme_support('html5');

    add_theme_support('loop-pagination');

    add_theme_support('automatic-feed-links');

    add_theme_support('post-formats', array('gallery', 'video', 'audio'));



    seramag_lite_register_new_image_sizes();



    global $content_width;

    if (!isset($content_width))

        $content_width = 870;



    register_nav_menus(array(

        'primary-nav'   => __('Primary Menu', 'seramag_lite'),

        'secondary-nav' => __('Secondary Menu', 'seramag_lite'),

        'footer-nav'    => __('Footer Menu', 'seramag_lite'),

    ));



    add_filter('seramag_lite_customization_init_options', 'seramag_lite_init_options');

    add_action('widgets_init', 'seramag_lite_register_sidebar');



    if (!is_admin()){

        add_action('wp_enqueue_scripts', 'seramag_lite_enqueue_scripts');

        add_filter('body_class', 'seramag_lite_body_class');

        add_filter('excerpt_more', '__return_false');

    }

}





function seramag_lite_register_new_image_sizes(){

    add_image_size('seramag_lite_slider', 770, 469, true);

    add_image_size('seramag_lite_blog', 175, 128, true);

    add_image_size('seramag_lite_medium_thumb', 360, 210, true);

    add_image_size('seramag_lite_related_posts', 360, 210, true);

    add_image_size('seramag_lite_adjacent_posts', 75, 75, true);    

    add_image_size('seramag_lite_feature_image', 815, 460, true);

}



function seramag_lite_enqueue_scripts(){

    global $post, $wp_styles, $is_IE;

    $dir = get_template_directory_uri();



    /*

     * --------------------------------------------------

     * STYLESHEET

     * --------------------------------------------------

     */

    wp_enqueue_style('seramag_lite-font-open-sans', '//fonts.googleapis.com/css?family=Open+Sans:400,300,600,700,800', array(), NULL);

    wp_enqueue_style('seramag_lite-font-oswald', '//fonts.googleapis.com/css?family=Oswald:400,300,700', array(), NULL);

    wp_enqueue_style('seramag_lite-font-roboto-condensed', '//fonts.googleapis.com/css?family=Roboto+Condensed:300italic,400italic,700italic,400,300,700', array(), NULL);    

    wp_enqueue_style('seramag_lite-bootstrap', "{$dir}/css/bootstrap.css", array(), NULL);

    wp_enqueue_style('seramag_lite-font-awesome', "{$dir}/css/font-awesome.css", array(), NULL);

    wp_enqueue_style('seramag_lite-navgoco', "{$dir}/css/navgoco.css", array(), NULL);

    wp_enqueue_style('seramag_lite-superfish', "{$dir}/css/superfish.css", array(), NULL);

    wp_enqueue_style('seramag_lite-megafish', "{$dir}/css/megafish.css", array(), NULL);

    wp_enqueue_style('seramag_lite-owl-carousel', "{$dir}/css/owl-carousel.css", array(), NULL);

    wp_enqueue_style('seramag_lite-owl-theme', "{$dir}/css/owl-theme.css", array(), NULL);

    wp_enqueue_style('seramag_lite-style', get_stylesheet_uri(), array(), NULL);



    if ($is_IE) {

        wp_register_style('seramag_lite-ie', $dir . '/css/ie.css', array(), NULL);

        wp_enqueue_style('seramag_lite-ie');

        $wp_styles->add_data('seramag_lite-ie', 'conditional', 'lt IE 9');



        wp_register_style('seramag_lite-ie9', $dir . '/css/ie9.css', array(), NULL);

        wp_enqueue_style('seramag_lite-ie9');

        $wp_styles->add_data('seramag_lite-ie9', 'conditional', 'IE 9');                

    }



    /*

     * --------------------------------------------------

     * JAVASCRIPT

     * --------------------------------------------------

     */

    if (is_singular())

        wp_enqueue_script('comment-reply');



    wp_enqueue_script('jquery');

    wp_enqueue_script('seramag_lite-modernizr', "{$dir}/js/modernizr.js", array('jquery'), NULL, TRUE);

    wp_enqueue_script('seramag_lite-bootstrap', "{$dir}/js/bootstrap.js", array('jquery'), NULL, TRUE);

    wp_enqueue_script('seramag_lite-caroufredsel', "{$dir}/js/caroufredsel.js", array('jquery'), NULL, TRUE);

    wp_enqueue_script('seramag_lite-navgoco', "{$dir}/js/navgoco.js", array('jquery'), NULL, TRUE);    

    wp_enqueue_script('seramag_lite-owl-carousel', "{$dir}/js/owl-carousel.js", array('jquery'), NULL, TRUE);

    wp_enqueue_script('seramag_lite-superfish', "{$dir}/js/superfish.js", array('jquery'), NULL, TRUE);    

    wp_enqueue_script('seramag_lite-custom', "{$dir}/js/custom.js", array('jquery'), NULL, TRUE);

    wp_localize_script('seramag_lite-custom', 'seramag_lite_vars', array());

}





function seramag_lite_body_class($classes){

    array_push($classes, 'kopa-sub-page');



    if(is_archive() || is_home()){

        array_push($classes, 'categories-1');

    }elseif(is_singular()){

        array_push($classes, 'kopa-single-page');        

    }



	return $classes;

}



function seramag_lite_init_options($options){

    $options['sections'][] = array(

        'id'    => 'seramag_lite_opt_general',

        'title' => __('General Settings', 'seramag_lite'));



    $options['settings'][] = array(

        'settings'  => 'is_show_signup_links',

        'label'     => __('Is show signup links (header)', 'seramag_lite'),

        'default'   => 1,

        'type'      => 'checkbox',        

        'section'   => 'seramag_lite_opt_general',

        'transport' => 'refresh');



    $options['settings'][] = array(

        'settings'  => 'is_show_post_format_links',

        'label'     => __('Is show post-format links (header)', 'seramag_lite'),

        'default'   => 1,

        'type'      => 'checkbox',        

        'section'   => 'seramag_lite_opt_general',

        'transport' => 'refresh');



    $options['settings'][] = array(

        'settings'  => 'is_show_headlines',

        'label'     => __('Is show headlines', 'seramag_lite'),

        'default'   => 1,

        'type'      => 'checkbox',        

        'section'   => 'seramag_lite_opt_general',

        'transport' => 'refresh');



    $options['settings'][] = array(

        'settings'    => 'logo',

        'label'       => __('Logo', 'seramag_lite'),

        'description' => __('Upload your logo image.', 'seramag_lite'),

        'default'     => '',

        'type'        => 'image',

        'section'     => 'seramag_lite_opt_general',

        'transport'   => 'refresh');



    $options['settings'][] = array(

        'settings'    => 'copyright',

        'label'       => __('Copyright', 'seramag_lite'),

        'description' => __('Your copyright information on footer.', 'seramag_lite'),

        'default'     => '',

        'type'        => 'textarea',

        'section'     => 'seramag_lite_opt_general',

        'transport'   => 'refresh');



    $options['settings'][] = array(

        'settings' => 'blog-layout',

        'label'    => __('Blog layout', 'seramag_lite'),

        'default'  => 'one-col',

        'type'     => 'select',

        'choices'  => array(

            'one-col' => __('One col', 'seramag_lite'),

            'two-cols' => __('Two cols', 'seramag_lite')

        ),

        'section'     => 'seramag_lite_opt_general',

        'transport'   => 'refresh');



    return $options;

}



function seramag_lite_register_sidebar(){



    $args = array(

        'before_widget' => '<div id="%1$s" class="widget clearfix %2$s">',

        'after_widget'  => '</div>',

        'before_title'  => '<h3 class="widget-title">',

        'after_title'   => '</h3>');



    $sidebars = array(

        array(

            'name'        => __( 'Main Top Sidebar', 'seramag_lite' ),

            'id'          => 'main-top-sidebar',

            'description' => __( 'The main-top sidebar for only archives page: blog, category, tag, ..', 'seramag_lite' )),        

        array(

            'name'        => __( 'Right Sidebar', 'seramag_lite' ),

            'id'          => 'right-sidebar',

            'description' => __( 'The right sidebar for blog or single.', 'seramag_lite' )),

        array(

            'name'        => __('Footer 1st', 'seramag_lite'),

            'id'          => 'footer-1-sidebar'),

        array(

            'name'        => __('Footer 2nd', 'seramag_lite'),

            'id'          => 'footer-2-sidebar'),

        array(

            'name'        => __('Footer 3rd', 'seramag_lite'),

            'id'          => 'footer-3-sidebar'),

        array(

            'name'        => __('Footer 4th', 'seramag_lite'),

            'id'          => 'footer-4-sidebar'),

        array(

            'name'        => __('Footer 5th', 'seramag_lite'),

            'id'          => 'footer-5-sidebar'),

        array(

            'name'        => __('Footer 6th', 'seramag_lite'),

            'id'          => 'footer-6-sidebar'),

    );



    foreach($sidebars as $sidebar){

        $sidebar = array_merge($sidebar, $args);

        register_sidebar($sidebar);

    }

}



function seramag_lite_log($message) {

    if (WP_DEBUG === true) {

        if (is_array($message) || is_object($message)) {

            error_log(print_r($message, true));

        } else {

            error_log($message);

        }

    }

}

